@@ -245,16 +245,16 @@ totem_pl_parser_add_rss (TotemPlParser *parser,
 	if (g_file_load_contents (file, NULL, &contents, &size, NULL, NULL) == FALSE)
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 
-	totem_pl_parser_cleanup_xml (contents);
-	xml_parser_init (contents, size, XML_PARSER_CASE_INSENSITIVE);
-	if (xml_parser_build_tree_with_options (&doc, XML_PARSER_RELAXED | XML_PARSER_MULTI_TEXT) < 0) {
+	doc = totem_pl_parser_parse_xml_relaxed (contents, size);
+	if (doc == NULL) {
 		g_free (contents);
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 	}
+
 	/* If the document has no name */
 	if (doc->name == NULL
 	    || (g_ascii_strcasecmp (doc->name , "rss") != 0
-	    	&& g_ascii_strcasecmp (doc->name , "rss\n") != 0)) {
+		&& g_ascii_strcasecmp (doc->name , "rss\n") != 0)) {
 		g_free (contents);
 		xml_parser_free_tree (doc);
 		return TOTEM_PL_PARSER_RESULT_ERROR;
@@ -495,11 +495,12 @@ totem_pl_parser_add_atom (TotemPlParser *parser,
 	if (g_file_load_contents (file, NULL, &contents, &size, NULL, NULL) == FALSE)
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 
-	xml_parser_init (contents, size, XML_PARSER_CASE_INSENSITIVE);
-	if (xml_parser_build_tree_with_options (&doc, XML_PARSER_RELAXED | XML_PARSER_MULTI_TEXT) < 0) {
+	doc = totem_pl_parser_parse_xml_relaxed (contents, size);
+	if (doc == NULL) {
 		g_free (contents);
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 	}
+
 	/* If the document has no name */
 	if (doc->name == NULL
 	    || g_ascii_strcasecmp (doc->name , "feed") != 0) {
@@ -569,16 +570,16 @@ check_header (char *data, gsize len)
 	unsigned flags;
 
 	if (len < 2 + 1 + 1 + 6)
-		return -1;
+		return 0;
 
 	/* Check signature */
 	if (memcmp (data, signature, sizeof (signature)) != 0)
-		return -1;
+		return 0;
 
 	/* verify flags and compression type */
 	flags  = data[3];
 	if (data[2] != Z_DEFLATED || (flags & ~GZIP_HEADER_FLAGS) != 0)
-		return -1;
+		return 0;
 
 	/* Get the uncompressed size */
 	/* FIXME, but how?  The size read here is modulo 2^32.  */
@@ -594,8 +595,8 @@ decompress_gzip (char *data, gsize len)
 	z_stream  stream;
 
 	retlen = check_header (data, len);
-	if (retlen < 0)
-		return NULL;
+	if (retlen == 0)
+		return g_strdup (data);
 
 	stream.zalloc    = (alloc_func)0;
 	stream.zfree     = (free_func)0;
@@ -656,7 +657,7 @@ totem_pl_parser_parse_itms_doc (xml_node_t *item)
 }
 
 static GFile *
-totem_pl_parser_get_feed_uri (const char *data, gsize len)
+totem_pl_parser_get_feed_uri (char *data, gsize len)
 {
 	xml_node_t* doc;
 	const char *uri;
@@ -664,8 +665,8 @@ totem_pl_parser_get_feed_uri (const char *data, gsize len)
 
 	uri = NULL;
 
-	xml_parser_init (data, len, XML_PARSER_CASE_INSENSITIVE);
-	if (xml_parser_build_tree_with_options (&doc, XML_PARSER_RELAXED | XML_PARSER_MULTI_TEXT) < 0)
+	doc = totem_pl_parser_parse_xml_relaxed (data, len);
+	if (doc == NULL)
 		return NULL;
 
 	/* If the document has no name */
@@ -777,11 +778,14 @@ totem_pl_parser_is_itms_feed (GFile *file)
 
 	uri = g_file_get_uri (file);
 
-	if (g_file_has_uri_scheme (file, "itms") != FALSE
-	    && strstr (uri, "phobos.apple.com") != NULL
-	    && strstr (uri, "viewPodcast") != NULL) {
-	    	g_free (uri);
-		return TRUE;
+	if (g_file_has_uri_scheme (file, "itms") != FALSE) {
+		if (strstr (uri, "phobos.apple.com") != NULL ||
+		    strstr (uri, "itunes.apple.com") != NULL) {
+			if (strstr (uri, "viewPodcast") != NULL) {
+				g_free (uri);
+				return TRUE;
+			}
+		}
 	}
 
 	if (strstr (uri, "phobos.apple.com/") != NULL
@@ -871,11 +875,12 @@ totem_pl_parser_add_opml (TotemPlParser *parser,
 	if (g_file_load_contents (file, NULL, &contents, &size, NULL, NULL) == FALSE)
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 
-	xml_parser_init (contents, size, XML_PARSER_CASE_INSENSITIVE);
-	if (xml_parser_build_tree_with_options (&doc, XML_PARSER_RELAXED | XML_PARSER_MULTI_TEXT) < 0) {
+	doc = totem_pl_parser_parse_xml_relaxed (contents, size);
+	if (doc == NULL) {
 		g_free (contents);
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 	}
+
 	/* If the document has no name */
 	if (doc->name == NULL
 	    || g_ascii_strcasecmp (doc->name , "opml") != 0) {
