@@ -32,6 +32,7 @@
 #include <gio/gio.h>
 #include <gio/gio.h>
 #include <string.h>
+#include "xmlparser.h"
 #else
 #include "totem-pl-parser-mini.h"
 #endif /* !TOTEM_PL_PARSER_MINI */
@@ -110,6 +111,8 @@ gboolean totem_pl_parser_write_buffer		(GOutputStream *stream,
 						 GError **error);
 char * totem_pl_parser_relative			(GFile *output,
 						 const char *filepath);
+char * totem_pl_parser_resolve_uri		(GFile *base_gfile,
+						 const char *relative_uri);
 TotemPlParserResult totem_pl_parser_parse_internal (TotemPlParser *parser,
 						    GFile *file,
 						    GFile *base_file);
@@ -124,7 +127,8 @@ void totem_pl_parser_add_uri			(TotemPlParser *parser,
 						 ...);
 gboolean totem_pl_parser_ignore			(TotemPlParser *parser,
 						 const char *uri);
-void totem_pl_parser_cleanup_xml		(char *string);
+xml_node_t * totem_pl_parser_parse_xml_relaxed	(char *contents,
+						 gsize size);
 
 #endif /* !TOTEM_PL_PARSER_MINI */
 
