@@ -144,8 +144,8 @@ totem_pl_parser_add_quicktime_metalink (TotemPlParser *parser,
 	if (g_file_load_contents (file, NULL, &contents, &size, NULL, NULL) == FALSE)
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 
-	xml_parser_init (contents, size, XML_PARSER_CASE_INSENSITIVE);
-	if (xml_parser_build_tree_with_options (&doc, XML_PARSER_RELAXED | XML_PARSER_MULTI_TEXT) < 0) {
+	doc = totem_pl_parser_parse_xml_relaxed (contents, size);
+	if (doc == NULL) {
 		g_free (contents);
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 	}
@@ -202,14 +202,8 @@ totem_pl_parser_add_quicktime (TotemPlParser *parser,
 			       GFile *base_file,
 			       gpointer data)
 {
-	if (data == NULL || totem_pl_parser_is_quicktime (data, strlen (data)) == NULL) {
-		char *uri;
-
-		uri = g_file_get_uri (file);
-		totem_pl_parser_add_one_uri (parser, uri, NULL);
-		g_free (uri);
-		return TOTEM_PL_PARSER_RESULT_SUCCESS;
-	}
+	if (data == NULL || totem_pl_parser_is_quicktime (data, strlen (data)) == NULL)
+		return TOTEM_PL_PARSER_RESULT_UNHANDLED;
 
 	return totem_pl_parser_add_quicktime_metalink (parser, file, base_file, data);
 }
