@@ -166,6 +166,7 @@ parse_asx_entry (TotemPlParser *parser, GFile *base_file, xml_node_t *parent)
 	xml_node_t *node;
 	TotemPlParserResult retval = TOTEM_PL_PARSER_RESULT_SUCCESS;
 	GFile *resolved;
+	char *resolved_uri;
 	const char *uri;
 	const char *title, *duration, *starttime, *author;
 	const char *moreinfo, *abstract, *copyright;
@@ -256,11 +257,9 @@ parse_asx_entry (TotemPlParser *parser, GFile *base_file, xml_node_t *parent)
 	if (uri == NULL)
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 
-
-	if (base_file != NULL && strstr (uri, "://") == NULL)
-		resolved = g_file_resolve_relative_path (base_file, uri);
-	else
-		resolved = g_file_new_for_uri (uri);
+	resolved_uri = totem_pl_parser_resolve_uri (base_file, uri);
+	resolved = g_file_new_for_uri (resolved_uri);
+	g_free (resolved_uri);
 
 	/* .asx files can contain references to other .asx files */
 	retval = totem_pl_parser_parse_internal (parser, resolved, NULL);
@@ -289,16 +288,16 @@ parse_asx_entryref (TotemPlParser *parser, GFile *base_file, xml_node_t *node)
 	TotemPlParserResult retval = TOTEM_PL_PARSER_RESULT_SUCCESS;
 	const char *uri;
 	GFile *resolved;
+	char *resolved_uri;
 
 	uri = xml_parser_get_property (node, "href");
 
 	if (uri == NULL)
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 
-	if (base_file != NULL && strstr (uri, "://") == NULL)
-		resolved = g_file_resolve_relative_path (base_file, uri);
-	else
-		resolved = g_file_new_for_uri (uri);
+	resolved_uri = totem_pl_parser_resolve_uri (base_file, uri);
+	resolved = g_file_new_for_uri (resolved_uri);
+	g_free (resolved_uri);
 
 	/* .asx files can contain references to other .asx files */
 	retval = totem_pl_parser_parse_internal (parser, resolved, NULL);
@@ -390,11 +389,12 @@ totem_pl_parser_add_asx (TotemPlParser *parser,
 	if (g_file_load_contents (file, NULL, &contents, &size, NULL, NULL) == FALSE)
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 
-	xml_parser_init (contents, size, XML_PARSER_CASE_INSENSITIVE);
-	if (xml_parser_build_tree_with_options (&doc, XML_PARSER_RELAXED | XML_PARSER_MULTI_TEXT) < 0) {
+	doc = totem_pl_parser_parse_xml_relaxed (contents, size);
+	if (doc == NULL) {
 		g_free (contents);
 		return TOTEM_PL_PARSER_RESULT_ERROR;
 	}
+
 	/* If the document has no name */
 	if (doc->name == NULL
 	    || g_ascii_strcasecmp (doc->name , "asx") != 0) {
